@@ -1,11 +1,12 @@
 from __future__ import absolute_import
 
-__version__ = 'v0.1.28'
+__version__ = 'v1.1.0'
 
 from . import emnist
 from . import kmnist
 from . import svhn
 from . import stl10
 from . import iris
+from . import wine_quality
 
-__all__ = ['emnist', 'kmnist', 'svhn', 'stl10', 'iris']
+__all__ = ['emnist', 'kmnist', 'svhn', 'stl10', 'iris', 'wine_quality']
